@@ -190,7 +190,7 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
     logging.info(f"{nna}")
 
     # Convert to categories and 
-    df_leads_clean, imp, mapping_dicts = preprocessing_training_common(df=df_leads_clean,
+    df_leads_clean, imp = preprocessing_training_common(df=df_leads_clean,
                                                                        config=config,
                                                                        industry_dictionary=industry_dictionary,
                                                                        mx_prob_dictionary=mx_prob_dictionary,
